==> airbridge_flutter_sdk-2.0.4.tar.gz: ios/Classes/EventAPI.swift <==
//
//  EventAPI.swift
//  airbridge_flutter_sdk
//
//  Created by WOF on 2021/07/05.
//

import Foundation
import AirBridge

struct EventAPI {
    let channel: FlutterMethodChannel
}

extension EventAPI {
    mutating func attachToChannel() {
        channel.setMethodCallHandler(handle(call:result:))
    }
    
    mutating func detachFromChannel() {
        channel.setMethodCallHandler(nil)
    }
}

extension EventAPI {
    func handle(call: FlutterMethodCall, result: FlutterResult) {
        let arguments = call.arguments as? [AnyHashable: Any] ?? [:]
        
        switch call.method {
        case "sendSignIn": sendSignIn(arguments, result)
        case "sendSignUp": sendSignUp(arguments, result)
        case "sendSignOut": sendSignOut(arguments, result)
        case "sendViewHome": sendEvent(category: ABCategory.viewHome, arguments, result)
        case "sendViewSearchResult": sendEvent(category: ABCategory.viewSearchResult, arguments, result)
        case "sendViewProductList": sendEvent(category: ABCategory.viewProductList, arguments, result)
        case "sendViewProductDetail": sendEvent(category: ABCategory.viewProductDetail, arguments, result)
        case "sendAddToCart": sendEvent(category: ABCategory.addToCart, arguments, result)
        case "sendPurchase": sendEvent(category: ABCategory.purchase, arguments, result)
        case "sendCustom": sendCustomEvent(arguments, result)
        default: result(FlutterMethodNotImplemented)
        }
    }
}

extension EventAPI {
    func sendSignIn(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        AirBridge.state().setUser(from: arguments["user"] as? [AnyHashable: Any])
        AirBridge.instance().trackEvent(category: ABCategory.signIn,
                                        option: arguments["option"] as? [AnyHashable: Any])
        
        result(nil)
    }
    
    func sendSignUp(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        AirBridge.state().setUser(from: arguments["user"] as? [AnyHashable: Any])
        AirBridge.instance().trackEvent(category: ABCategory.signUp,
                                        option: arguments["option"] as? [AnyHashable: Any])
        
        result(nil)
    }
    
    func sendSignOut(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        AirBridge.instance().trackEvent(category: ABCategory.signOut,
                                        option: arguments["option"] as? [AnyHashable: Any])
        AirBridge.state().setUser(from: nil)
        
        result(nil)
    }
    
    func sendCustomEvent(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        guard let category = arguments["category"] as? String else {
            result(FlutterMethodNotImplemented)
            return
        }
        
        AirBridge.instance().trackEvent(category: category,
                                        option: arguments["option"] as? [AnyHashable: Any])
        
        result(nil)
    }
    
    func sendEvent(category: String, _ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        AirBridge.instance().trackEvent(category: category,
                                        option: arguments["option"] as? [AnyHashable: Any])
        
        result(nil)
    }
}

extension EventAPI {
    static func fromPlugin(_ registrar: FlutterPluginRegistrar) -> EventAPI {
        return EventAPI(channel: FlutterMethodChannel(name: "airbridge_flutter_sdk/method/event",
                                                      binaryMessenger: registrar.messenger()))
    }
}

==> airbridge_flutter_sdk-3.1.2.tar.gz: ios/Classes/EventAPI.swift <==
//
//  EventAPI.swift
//  airbridge_flutter_sdk
//
//  Created by WOF on 2021/07/05.
//

import Foundation
import AirBridge

struct EventAPI {
    let channel: FlutterMethodChannel
}

extension EventAPI {
    mutating func attachToChannel() {
        channel.setMethodCallHandler(handle(call:result:))
    }
    
    mutating func detachFromChannel() {
        channel.setMethodCallHandler(nil)
    }
}

extension EventAPI {
    func handle(call: FlutterMethodCall, result: FlutterResult) {
        let arguments = call.arguments as? [AnyHashable: Any] ?? [:]
        
        switch call.method {
        case "trackEvent": trackEvent(arguments, result)
        default: result(FlutterMethodNotImplemented)
        }
    }
}

extension EventAPI {

    func trackEvent(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        guard let category = arguments["category"] as? String else {
            result(FlutterError.init(code: "BAD_ARGS",
                                     message: "category not found",
                                     details: nil))
            return
        }
        
        AirBridge.instance().trackEvent(category: category,
                                        option: arguments["option"] as? [AnyHashable: Any])
        
        result(nil)
    }
}

extension EventAPI {
    static func fromPlugin(_ registrar: FlutterPluginRegistrar) -> EventAPI {
        return EventAPI(channel: FlutterMethodChannel(name: "airbridge_flutter_sdk/method/event",
                                                      binaryMessenger: registrar.messenger()))
    }
}
